APOETC
======
This package is used to calculate an exposure time based on a desired signal to noise ratio. See documentation `here <https://apoexposuretimecalculator.github.io/APOExptime/>`_.


Limitations
------------
This package was intented only for the Astrophysical Research Consortium (ARC) 3.5m telescope at the Apache Point Observatory.